@@ -9,10 +9,12 @@ class MainUser(Node):
     name = ndb.StringProperty(required=True)
     email = Email(required=True)
     groups = ndb.StringProperty(repeated=True)
+    locale = ndb.StringProperty(indexed=False)
+    timezone = ndb.StringProperty(indexed=False)
 
     @classmethod
     def query_email_starts_with(cls, prefix=''):
-        last_str_with_prefix = prefix + unichr(65525) # this is the last unichar supported on windows systems
+        last_str_with_prefix = prefix + unichr(65525)  # this is the last unichar supported on windows systems
         return cls.query(cls.email >= prefix, cls.email < last_str_with_prefix).order(cls.email)
 
     @classmethod
